@@ -99,7 +99,7 @@ def E(expr,color ="red"):
     texto = latemix(izquierda) + " = " + latemix(derecha)
     return IPython.display.Latex(texto)
   elif isinstance(expr,list):#Si tenemos un componente
-    texto = sy.latex(expr[0]) + " = " + latemix(expr[1])
+    texto = sympy.latex(expr[0]) + " = " + latemix(expr[1])
     return IPython.display.Latex(texto)
 
 #def E(expr,color = "red"):
